@@ -1,7 +1,7 @@
 '''
 # `data_google_storage_object_signed_url`
 
-Refer to the Terraform Registory for docs: [`data_google_storage_object_signed_url`](https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url).
+Refer to the Terraform Registory for docs: [`data_google_storage_object_signed_url`](https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url).
 '''
 import abc
 import builtins
@@ -17,20 +17,20 @@ from typeguard import check_type
 
 from .._jsii import *
 
-import cdktf
-import constructs
+import cdktf as _cdktf_9a9027ec
+import constructs as _constructs_77d1e7e8
 
 
 class DataGoogleStorageObjectSignedUrl(
-    cdktf.TerraformDataSource,
+    _cdktf_9a9027ec.TerraformDataSource,
     metaclass=jsii.JSIIMeta,
     jsii_type="@cdktf/provider-google-beta.dataGoogleStorageObjectSignedUrl.DataGoogleStorageObjectSignedUrl",
 ):
-    '''Represents a {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url google_storage_object_signed_url}.'''
+    '''Represents a {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url google_storage_object_signed_url}.'''
 
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id_: builtins.str,
         *,
         bucket: builtins.str,
@@ -42,27 +42,27 @@ class DataGoogleStorageObjectSignedUrl(
         extension_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         http_method: typing.Optional[builtins.str] = None,
         id: typing.Optional[builtins.str] = None,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-        count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
     ) -> None:
-        '''Create a new {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url google_storage_object_signed_url} Data Source.
+        '''Create a new {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url google_storage_object_signed_url} Data Source.
 
         :param scope: The scope in which to define this construct.
         :param id_: The scoped construct ID. Must be unique amongst siblings in the same scope
-        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#bucket DataGoogleStorageObjectSignedUrl#bucket}.
-        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#path DataGoogleStorageObjectSignedUrl#path}.
-        :param content_md5: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#content_md5 DataGoogleStorageObjectSignedUrl#content_md5}.
-        :param content_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#content_type DataGoogleStorageObjectSignedUrl#content_type}.
-        :param credentials: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#credentials DataGoogleStorageObjectSignedUrl#credentials}.
-        :param duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#duration DataGoogleStorageObjectSignedUrl#duration}.
-        :param extension_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#extension_headers DataGoogleStorageObjectSignedUrl#extension_headers}.
-        :param http_method: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#http_method DataGoogleStorageObjectSignedUrl#http_method}.
-        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#id DataGoogleStorageObjectSignedUrl#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param bucket: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#bucket DataGoogleStorageObjectSignedUrl#bucket}.
+        :param path: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#path DataGoogleStorageObjectSignedUrl#path}.
+        :param content_md5: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#content_md5 DataGoogleStorageObjectSignedUrl#content_md5}.
+        :param content_type: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#content_type DataGoogleStorageObjectSignedUrl#content_type}.
+        :param credentials: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#credentials DataGoogleStorageObjectSignedUrl#credentials}.
+        :param duration: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#duration DataGoogleStorageObjectSignedUrl#duration}.
+        :param extension_headers: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#extension_headers DataGoogleStorageObjectSignedUrl#extension_headers}.
+        :param http_method: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#http_method DataGoogleStorageObjectSignedUrl#http_method}.
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#id DataGoogleStorageObjectSignedUrl#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         :param connection: 
         :param count: 
         :param depends_on: 
@@ -72,7 +72,7 @@ class DataGoogleStorageObjectSignedUrl(
         :param provisioners: 
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(DataGoogleStorageObjectSignedUrl.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__25decc267cbadd4824085dd040122e55bb4209e8085d1d0f18f5df298704dcdb)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id_", value=id_, expected_type=type_hints["id_"])
         config = DataGoogleStorageObjectSignedUrlConfig(
@@ -193,7 +193,7 @@ class DataGoogleStorageObjectSignedUrl(
     @bucket.setter
     def bucket(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "bucket").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__b82335df44d8f8e20a350c8748a9282ecea5b6e5987ad8f8512606c4e22cdade)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "bucket", value)
 
@@ -205,7 +205,7 @@ class DataGoogleStorageObjectSignedUrl(
     @content_md5.setter
     def content_md5(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "content_md5").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e2852f183922ac1eb7209f772a8db949714c78239773be1ea3b07b9ddb40ed20)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "contentMd5", value)
 
@@ -217,7 +217,7 @@ class DataGoogleStorageObjectSignedUrl(
     @content_type.setter
     def content_type(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "content_type").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__d20a232cac83914e2930704843c87bad18a65d1500392f83cfc4604448d23613)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "contentType", value)
 
@@ -229,7 +229,7 @@ class DataGoogleStorageObjectSignedUrl(
     @credentials.setter
     def credentials(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "credentials").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__397c5a73538ab17ef7d43fe6f1d4899e809fbaf901b295ccea0b05559f7fb642)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "credentials", value)
 
@@ -241,7 +241,7 @@ class DataGoogleStorageObjectSignedUrl(
     @duration.setter
     def duration(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "duration").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__37e19d3b776c57a8af967ea77da51e224f1d675ac254936a7e93ac3b861255c6)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "duration", value)
 
@@ -256,7 +256,7 @@ class DataGoogleStorageObjectSignedUrl(
         value: typing.Mapping[builtins.str, builtins.str],
     ) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "extension_headers").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2ef62477d93325d03f9c86786493d1ec4644f7dab74a9f58cba2fef12c67a0e9)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "extensionHeaders", value)
 
@@ -268,7 +268,7 @@ class DataGoogleStorageObjectSignedUrl(
     @http_method.setter
     def http_method(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "http_method").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__2a68a11305b9d4fc68402d374e4af28c2f633f3f236c24361f55b4928b58ef19)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "httpMethod", value)
 
@@ -280,7 +280,7 @@ class DataGoogleStorageObjectSignedUrl(
     @id.setter
     def id(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "id").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__42f2df59c0fa647e32897b929b40ae527baefcdb135156d3c49ecdc3ccaa0dfa)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "id", value)
 
@@ -292,14 +292,14 @@ class DataGoogleStorageObjectSignedUrl(
     @path.setter
     def path(self, value: builtins.str) -> None:
         if __debug__:
-            type_hints = typing.get_type_hints(getattr(DataGoogleStorageObjectSignedUrl, "path").fset)
+            type_hints = typing.get_type_hints(_typecheckingstub__e860da9089898489159b8a23042c011a99cf879ccaed0b359dc9ee7803912a05)
             check_type(argname="argument value", value=value, expected_type=type_hints["value"])
         jsii.set(self, "path", value)
 
 
 @jsii.data_type(
     jsii_type="@cdktf/provider-google-beta.dataGoogleStorageObjectSignedUrl.DataGoogleStorageObjectSignedUrlConfig",
-    jsii_struct_bases=[cdktf.TerraformMetaArguments],
+    jsii_struct_bases=[_cdktf_9a9027ec.TerraformMetaArguments],
     name_mapping={
         "connection": "connection",
         "count": "count",
@@ -319,17 +319,17 @@ class DataGoogleStorageObjectSignedUrl(
         "id": "id",
     },
 )
-class DataGoogleStorageObjectSignedUrlConfig(cdktf.TerraformMetaArguments):
+class DataGoogleStorageObjectSignedUrlConfig(_cdktf_9a9027ec.TerraformMetaArguments):
     def __init__(
         self,
         *,
-        connection: typing.Optional[typing.Union[typing.Union[cdktf.SSHProvisionerConnection, typing.Dict[str, typing.Any]], typing.Union[cdktf.WinrmProvisionerConnection, typing.Dict[str, typing.Any]]]] = None,
-        count: typing.Optional[jsii.Number] = None,
-        depends_on: typing.Optional[typing.Sequence[cdktf.ITerraformDependable]] = None,
-        for_each: typing.Optional[cdktf.ITerraformIterator] = None,
-        lifecycle: typing.Optional[typing.Union[cdktf.TerraformResourceLifecycle, typing.Dict[str, typing.Any]]] = None,
-        provider: typing.Optional[cdktf.TerraformProvider] = None,
-        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[cdktf.FileProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.LocalExecProvisioner, typing.Dict[str, typing.Any]], typing.Union[cdktf.RemoteExecProvisioner, typing.Dict[str, typing.Any]]]]] = None,
+        connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+        count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
+        depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+        for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+        lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+        provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+        provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
         bucket: builtins.str,
         path: builtins.str,
         content_md5: typing.Optional[builtins.str] = None,
@@ -348,20 +348,20 @@ class DataGoogleStorageObjectSignedUrlConfig(cdktf.TerraformMetaArguments):
         :param lifecycle: 
         :param provider: 
         :param provisioners: 
-        :param bucket: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#bucket DataGoogleStorageObjectSignedUrl#bucket}.
-        :param path: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#path DataGoogleStorageObjectSignedUrl#path}.
-        :param content_md5: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#content_md5 DataGoogleStorageObjectSignedUrl#content_md5}.
-        :param content_type: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#content_type DataGoogleStorageObjectSignedUrl#content_type}.
-        :param credentials: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#credentials DataGoogleStorageObjectSignedUrl#credentials}.
-        :param duration: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#duration DataGoogleStorageObjectSignedUrl#duration}.
-        :param extension_headers: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#extension_headers DataGoogleStorageObjectSignedUrl#extension_headers}.
-        :param http_method: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#http_method DataGoogleStorageObjectSignedUrl#http_method}.
-        :param id: Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#id DataGoogleStorageObjectSignedUrl#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
+        :param bucket: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#bucket DataGoogleStorageObjectSignedUrl#bucket}.
+        :param path: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#path DataGoogleStorageObjectSignedUrl#path}.
+        :param content_md5: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#content_md5 DataGoogleStorageObjectSignedUrl#content_md5}.
+        :param content_type: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#content_type DataGoogleStorageObjectSignedUrl#content_type}.
+        :param credentials: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#credentials DataGoogleStorageObjectSignedUrl#credentials}.
+        :param duration: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#duration DataGoogleStorageObjectSignedUrl#duration}.
+        :param extension_headers: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#extension_headers DataGoogleStorageObjectSignedUrl#extension_headers}.
+        :param http_method: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#http_method DataGoogleStorageObjectSignedUrl#http_method}.
+        :param id: Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#id DataGoogleStorageObjectSignedUrl#id}. Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2. If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
         '''
         if isinstance(lifecycle, dict):
-            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
+            lifecycle = _cdktf_9a9027ec.TerraformResourceLifecycle(**lifecycle)
         if __debug__:
-            type_hints = typing.get_type_hints(DataGoogleStorageObjectSignedUrlConfig.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__7ee2e2b619fba231f2aa1bde0907f197bce46225acc00df72cd319d7fed33643)
             check_type(argname="argument connection", value=connection, expected_type=type_hints["connection"])
             check_type(argname="argument count", value=count, expected_type=type_hints["count"])
             check_type(argname="argument depends_on", value=depends_on, expected_type=type_hints["depends_on"])
@@ -378,7 +378,7 @@ class DataGoogleStorageObjectSignedUrlConfig(cdktf.TerraformMetaArguments):
             check_type(argname="argument extension_headers", value=extension_headers, expected_type=type_hints["extension_headers"])
             check_type(argname="argument http_method", value=http_method, expected_type=type_hints["http_method"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "bucket": bucket,
             "path": path,
         }
@@ -414,98 +414,102 @@ class DataGoogleStorageObjectSignedUrlConfig(cdktf.TerraformMetaArguments):
     @builtins.property
     def connection(
         self,
-    ) -> typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]]:
+    ) -> typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("connection")
-        return typing.cast(typing.Optional[typing.Union[cdktf.SSHProvisionerConnection, cdktf.WinrmProvisionerConnection]], result)
+        return typing.cast(typing.Optional[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, _cdktf_9a9027ec.WinrmProvisionerConnection]], result)
 
     @builtins.property
-    def count(self) -> typing.Optional[jsii.Number]:
+    def count(
+        self,
+    ) -> typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("count")
-        return typing.cast(typing.Optional[jsii.Number], result)
+        return typing.cast(typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]], result)
 
     @builtins.property
-    def depends_on(self) -> typing.Optional[typing.List[cdktf.ITerraformDependable]]:
+    def depends_on(
+        self,
+    ) -> typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("depends_on")
-        return typing.cast(typing.Optional[typing.List[cdktf.ITerraformDependable]], result)
+        return typing.cast(typing.Optional[typing.List[_cdktf_9a9027ec.ITerraformDependable]], result)
 
     @builtins.property
-    def for_each(self) -> typing.Optional[cdktf.ITerraformIterator]:
+    def for_each(self) -> typing.Optional[_cdktf_9a9027ec.ITerraformIterator]:
         '''
         :stability: experimental
         '''
         result = self._values.get("for_each")
-        return typing.cast(typing.Optional[cdktf.ITerraformIterator], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.ITerraformIterator], result)
 
     @builtins.property
-    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
+    def lifecycle(self) -> typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle]:
         '''
         :stability: experimental
         '''
         result = self._values.get("lifecycle")
-        return typing.cast(typing.Optional[cdktf.TerraformResourceLifecycle], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformResourceLifecycle], result)
 
     @builtins.property
-    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
+    def provider(self) -> typing.Optional[_cdktf_9a9027ec.TerraformProvider]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provider")
-        return typing.cast(typing.Optional[cdktf.TerraformProvider], result)
+        return typing.cast(typing.Optional[_cdktf_9a9027ec.TerraformProvider], result)
 
     @builtins.property
     def provisioners(
         self,
-    ) -> typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]]:
+    ) -> typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]]:
         '''
         :stability: experimental
         '''
         result = self._values.get("provisioners")
-        return typing.cast(typing.Optional[typing.List[typing.Union[cdktf.FileProvisioner, cdktf.LocalExecProvisioner, cdktf.RemoteExecProvisioner]]], result)
+        return typing.cast(typing.Optional[typing.List[typing.Union[_cdktf_9a9027ec.FileProvisioner, _cdktf_9a9027ec.LocalExecProvisioner, _cdktf_9a9027ec.RemoteExecProvisioner]]], result)
 
     @builtins.property
     def bucket(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#bucket DataGoogleStorageObjectSignedUrl#bucket}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#bucket DataGoogleStorageObjectSignedUrl#bucket}.'''
         result = self._values.get("bucket")
         assert result is not None, "Required property 'bucket' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def path(self) -> builtins.str:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#path DataGoogleStorageObjectSignedUrl#path}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#path DataGoogleStorageObjectSignedUrl#path}.'''
         result = self._values.get("path")
         assert result is not None, "Required property 'path' is missing"
         return typing.cast(builtins.str, result)
 
     @builtins.property
     def content_md5(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#content_md5 DataGoogleStorageObjectSignedUrl#content_md5}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#content_md5 DataGoogleStorageObjectSignedUrl#content_md5}.'''
         result = self._values.get("content_md5")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def content_type(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#content_type DataGoogleStorageObjectSignedUrl#content_type}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#content_type DataGoogleStorageObjectSignedUrl#content_type}.'''
         result = self._values.get("content_type")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def credentials(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#credentials DataGoogleStorageObjectSignedUrl#credentials}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#credentials DataGoogleStorageObjectSignedUrl#credentials}.'''
         result = self._values.get("credentials")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def duration(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#duration DataGoogleStorageObjectSignedUrl#duration}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#duration DataGoogleStorageObjectSignedUrl#duration}.'''
         result = self._values.get("duration")
         return typing.cast(typing.Optional[builtins.str], result)
 
@@ -513,19 +517,19 @@ class DataGoogleStorageObjectSignedUrlConfig(cdktf.TerraformMetaArguments):
     def extension_headers(
         self,
     ) -> typing.Optional[typing.Mapping[builtins.str, builtins.str]]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#extension_headers DataGoogleStorageObjectSignedUrl#extension_headers}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#extension_headers DataGoogleStorageObjectSignedUrl#extension_headers}.'''
         result = self._values.get("extension_headers")
         return typing.cast(typing.Optional[typing.Mapping[builtins.str, builtins.str]], result)
 
     @builtins.property
     def http_method(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#http_method DataGoogleStorageObjectSignedUrl#http_method}.'''
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#http_method DataGoogleStorageObjectSignedUrl#http_method}.'''
         result = self._values.get("http_method")
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def id(self) -> typing.Optional[builtins.str]:
-        '''Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/google-beta/d/google_storage_object_signed_url#id DataGoogleStorageObjectSignedUrl#id}.
+        '''Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/google-beta/4.62.0/docs/data-sources/google_storage_object_signed_url#id DataGoogleStorageObjectSignedUrl#id}.
 
         Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
         If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
@@ -551,3 +555,103 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__25decc267cbadd4824085dd040122e55bb4209e8085d1d0f18f5df298704dcdb(
+    scope: _constructs_77d1e7e8.Construct,
+    id_: builtins.str,
+    *,
+    bucket: builtins.str,
+    path: builtins.str,
+    content_md5: typing.Optional[builtins.str] = None,
+    content_type: typing.Optional[builtins.str] = None,
+    credentials: typing.Optional[builtins.str] = None,
+    duration: typing.Optional[builtins.str] = None,
+    extension_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    http_method: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__b82335df44d8f8e20a350c8748a9282ecea5b6e5987ad8f8512606c4e22cdade(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e2852f183922ac1eb7209f772a8db949714c78239773be1ea3b07b9ddb40ed20(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__d20a232cac83914e2930704843c87bad18a65d1500392f83cfc4604448d23613(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__397c5a73538ab17ef7d43fe6f1d4899e809fbaf901b295ccea0b05559f7fb642(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__37e19d3b776c57a8af967ea77da51e224f1d675ac254936a7e93ac3b861255c6(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2ef62477d93325d03f9c86786493d1ec4644f7dab74a9f58cba2fef12c67a0e9(
+    value: typing.Mapping[builtins.str, builtins.str],
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__2a68a11305b9d4fc68402d374e4af28c2f633f3f236c24361f55b4928b58ef19(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__42f2df59c0fa647e32897b929b40ae527baefcdb135156d3c49ecdc3ccaa0dfa(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__e860da9089898489159b8a23042c011a99cf879ccaed0b359dc9ee7803912a05(
+    value: builtins.str,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__7ee2e2b619fba231f2aa1bde0907f197bce46225acc00df72cd319d7fed33643(
+    *,
+    connection: typing.Optional[typing.Union[typing.Union[_cdktf_9a9027ec.SSHProvisionerConnection, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.WinrmProvisionerConnection, typing.Dict[builtins.str, typing.Any]]]] = None,
+    count: typing.Optional[typing.Union[jsii.Number, _cdktf_9a9027ec.TerraformCount]] = None,
+    depends_on: typing.Optional[typing.Sequence[_cdktf_9a9027ec.ITerraformDependable]] = None,
+    for_each: typing.Optional[_cdktf_9a9027ec.ITerraformIterator] = None,
+    lifecycle: typing.Optional[typing.Union[_cdktf_9a9027ec.TerraformResourceLifecycle, typing.Dict[builtins.str, typing.Any]]] = None,
+    provider: typing.Optional[_cdktf_9a9027ec.TerraformProvider] = None,
+    provisioners: typing.Optional[typing.Sequence[typing.Union[typing.Union[_cdktf_9a9027ec.FileProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.LocalExecProvisioner, typing.Dict[builtins.str, typing.Any]], typing.Union[_cdktf_9a9027ec.RemoteExecProvisioner, typing.Dict[builtins.str, typing.Any]]]]] = None,
+    bucket: builtins.str,
+    path: builtins.str,
+    content_md5: typing.Optional[builtins.str] = None,
+    content_type: typing.Optional[builtins.str] = None,
+    credentials: typing.Optional[builtins.str] = None,
+    duration: typing.Optional[builtins.str] = None,
+    extension_headers: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
+    http_method: typing.Optional[builtins.str] = None,
+    id: typing.Optional[builtins.str] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
